@@ -16,7 +16,7 @@
  ************************************************************************* */
 
 
-#include "config.h"
+#include <config.h>
 #include "renderer.h"
 
 #include <QDir>
